abacusai.document_retriever_config — AbacusAI documentation

# `abacusai.document_retriever_config`

## Module Contents

### Classes

`DocumentRetrieverConfig` | A config for document retriever creation.

class abacusai.document_retriever_config.DocumentRetrieverConfig(client, chunkSize=None, chunkOverlapFraction=None, textEncoder=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A config for document retriever creation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chunkSize (int) – The size of chunks for vector store, i.e., maximum number of words in the chunk.

    - chunkOverlapFraction (float) – The fraction of overlap between two consecutive chunks.

    - textEncoder (str) – The text encoder used to encode texts in the vector store.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict